package thesisGenerator.model;

import java.util.ArrayList;
import java.util.Random;

/**
 * Thesis generator model.
 * @author Máté Cserép
 */
public class GeneratorModel {
    private Integer questionCount;
    private Integer periodCount;
    private Integer questionNumber;
    private ArrayList<Integer> history;
    
    private final Random generator;
    
    /**
     * Creates thesis generator model.
     * @param questionCount Number of questions.
     * @param periodCount  Length of period.
     */
    public GeneratorModel(Integer questionCount, Integer periodCount) {
        this.questionCount = questionCount;
        this.periodCount = periodCount;
        history = new ArrayList<>();
        
        generator = new Random();
    }
    
    /**
     * Generates a new valid thesis number.
     * @return The generated thesis number.
     */
    public Integer Generate() {
       questionNumber = generator.nextInt(questionCount) + 1;
       while(history.contains(questionNumber))
           questionNumber = generator.nextInt(questionCount) + 1;
       
       return questionNumber;
    }
    
    /**
     * Takes the last generated thesis number.
     */
    public void Take() {
        history.add(questionNumber);
        if(history.size() > periodCount)
            history.remove(0);
    }
    
    public Integer getQuestionCount() {
        return questionCount;
    }
    
    public Integer getPeriodCount() {
        return periodCount;
    }
    
    public Integer getQuestionNumber() {
        return questionNumber;
    }
    
    public void setQuestionCount(Integer value) {
        if(value <= 0)
            throw new IllegalArgumentException("Thesis count must be a positive number.");
        
        questionCount = value;
        if(periodCount > questionCount) {
            periodCount = value - 1;
            
            history.removeIf(n -> n > value);
            while(history.size() > periodCount)
                history.remove(0);
        }
    }
    public void setPeriodCount(Integer value) {
        if(value < 0)
            throw new IllegalArgumentException("Period count must be a non-negative number.");
        
        if(value >= questionCount)
            throw new IllegalArgumentException("Period count must be smaller than the thesis count.");
        
        periodCount = value;
        while(history.size() > periodCount)
            history.remove(0);
    }
}
