package thesisGenerator.view;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.Timer;
import thesisGenerator.model.GeneratorModel;

/**
 * Thesis generator view.
 * @author Máté Cserép
 */
public class MainFrame extends javax.swing.JFrame {
    
    private boolean isRunning = false;
    private final GeneratorModel model;
    private final Timer timer;
    
    /**
     * Creates new form MainFrame.
     */
    public MainFrame() {
        model = new GeneratorModel(10, 0);
        timer = new Timer(20, new ActionListener() {
            public void actionPerformed(ActionEvent evt) {
                txtNumber.setText(model.Generate().toString());
            }
        });
        
        initComponents();
        spinnerQuestion.setValue(model.getQuestionCount());
        spinnerPeriod.setValue(model.getPeriodCount());
    }

    /**
     * This method is called from within the constructor to initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is always
     * regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        txtNumber = new javax.swing.JTextField();
        btnStartStop = new javax.swing.JButton();
        spinnerQuestion = new javax.swing.JSpinner();
        spinnerPeriod = new javax.swing.JSpinner();
        lblQuestion = new javax.swing.JLabel();
        lblPeriod = new javax.swing.JLabel();

        setDefaultCloseOperation(javax.swing.WindowConstants.EXIT_ON_CLOSE);
        setResizable(false);

        txtNumber.setEditable(false);
        txtNumber.setFont(new java.awt.Font("Tahoma", 1, 48)); // NOI18N
        txtNumber.setHorizontalAlignment(javax.swing.JTextField.CENTER);
        txtNumber.setToolTipText("");

        btnStartStop.setFont(new java.awt.Font("Tahoma", 1, 14)); // NOI18N
        btnStartStop.setText("START");
        btnStartStop.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                btnStartStopActionPerformed(evt);
            }
        });

        spinnerQuestion.addChangeListener(new javax.swing.event.ChangeListener() {
            public void stateChanged(javax.swing.event.ChangeEvent evt) {
                spinnerQuestionStateChanged(evt);
            }
        });

        spinnerPeriod.addChangeListener(new javax.swing.event.ChangeListener() {
            public void stateChanged(javax.swing.event.ChangeEvent evt) {
                spinnerPeriodStateChanged(evt);
            }
        });

        lblQuestion.setLabelFor(spinnerQuestion);
        lblQuestion.setText("Question count:");

        lblPeriod.setLabelFor(spinnerPeriod);
        lblPeriod.setText("Period count:");
        lblPeriod.setToolTipText("");

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(getContentPane());
        getContentPane().setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
                    .addComponent(txtNumber)
                    .addGroup(layout.createSequentialGroup()
                        .addComponent(lblQuestion)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(spinnerQuestion, javax.swing.GroupLayout.PREFERRED_SIZE, 39, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(lblPeriod)
                        .addPreferredGap(javax.swing.LayoutStyle.ComponentPlacement.RELATED)
                        .addComponent(spinnerPeriod, javax.swing.GroupLayout.PREFERRED_SIZE, 39, javax.swing.GroupLayout.PREFERRED_SIZE)
                        .addGap(0, 0, Short.MAX_VALUE)))
                .addContainerGap())
            .addGroup(layout.createSequentialGroup()
                .addGap(97, 97, 97)
                .addComponent(btnStartStop, javax.swing.GroupLayout.PREFERRED_SIZE, 88, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGroup(layout.createSequentialGroup()
                .addContainerGap()
                .addComponent(txtNumber, javax.swing.GroupLayout.PREFERRED_SIZE, 97, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addGap(18, 18, 18)
                .addGroup(layout.createParallelGroup(javax.swing.GroupLayout.Alignment.BASELINE)
                    .addComponent(lblQuestion)
                    .addComponent(spinnerQuestion, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE)
                    .addComponent(lblPeriod)
                    .addComponent(spinnerPeriod, javax.swing.GroupLayout.PREFERRED_SIZE, javax.swing.GroupLayout.DEFAULT_SIZE, javax.swing.GroupLayout.PREFERRED_SIZE))
                .addGap(18, 18, 18)
                .addComponent(btnStartStop, javax.swing.GroupLayout.PREFERRED_SIZE, 38, javax.swing.GroupLayout.PREFERRED_SIZE)
                .addContainerGap(javax.swing.GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE))
        );

        pack();
    }// </editor-fold>//GEN-END:initComponents

    private void btnStartStopActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_btnStartStopActionPerformed
        if(!isRunning) {
            timer.start();
            btnStartStop.setText("STOP");
        }
        else {
            timer.stop();
            model.Take();            
            btnStartStop.setText("START");
        }
        isRunning = !isRunning;
    }//GEN-LAST:event_btnStartStopActionPerformed

    private void spinnerQuestionStateChanged(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_spinnerQuestionStateChanged
        model.setQuestionCount(Integer.parseInt(spinnerQuestion.getValue().toString()));
        spinnerPeriod.setValue(model.getPeriodCount());
    }//GEN-LAST:event_spinnerQuestionStateChanged

    private void spinnerPeriodStateChanged(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_spinnerPeriodStateChanged
        model.setPeriodCount(Integer.parseInt(spinnerPeriod.getValue().toString()));
    }//GEN-LAST:event_spinnerPeriodStateChanged

    /**
     * @param args the command line arguments
     */
    public static void main(String args[]) {
        /* Set the Nimbus look and feel */
        //<editor-fold defaultstate="collapsed" desc=" Look and feel setting code (optional) ">
        /* If Nimbus (introduced in Java SE 6) is not available, stay with the default look and feel.
         * For details see http://download.oracle.com/javase/tutorial/uiswing/lookandfeel/plaf.html 
         */
        try {
            for (javax.swing.UIManager.LookAndFeelInfo info : javax.swing.UIManager.getInstalledLookAndFeels()) {
                if ("Nimbus".equals(info.getName())) {
                    javax.swing.UIManager.setLookAndFeel(info.getClassName());
                    break;
                }
            }
        } catch (ClassNotFoundException ex) {
            java.util.logging.Logger.getLogger(MainFrame.class.getName()).log(java.util.logging.Level.SEVERE, null, ex);
        } catch (InstantiationException ex) {
            java.util.logging.Logger.getLogger(MainFrame.class.getName()).log(java.util.logging.Level.SEVERE, null, ex);
        } catch (IllegalAccessException ex) {
            java.util.logging.Logger.getLogger(MainFrame.class.getName()).log(java.util.logging.Level.SEVERE, null, ex);
        } catch (javax.swing.UnsupportedLookAndFeelException ex) {
            java.util.logging.Logger.getLogger(MainFrame.class.getName()).log(java.util.logging.Level.SEVERE, null, ex);
        }
        //</editor-fold>

        /* Create and display the form */
        java.awt.EventQueue.invokeLater(new Runnable() {
            public void run() {
                new MainFrame().setVisible(true);
            }
        });
    }

    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JButton btnStartStop;
    private javax.swing.JLabel lblPeriod;
    private javax.swing.JLabel lblQuestion;
    private javax.swing.JSpinner spinnerPeriod;
    private javax.swing.JSpinner spinnerQuestion;
    private javax.swing.JTextField txtNumber;
    // End of variables declaration//GEN-END:variables
}
